<?php

namespace Drupal\gnode_request\Plugin\Validation\Constraint;

use Drupal\group\Entity\GroupRelationshipInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Checks user membership.
 */
class GroupNodeRequestValidator extends ConstraintValidator {

  /**
   * Type-hinting in parent Symfony class is off, let's fix that.
   *
   * @var \Symfony\Component\Validator\Context\ExecutionContextInterface
   */
  protected $context;

  /**
   * {@inheritdoc}
   */
  public function validate($group_relationship, Constraint $constraint) {

    assert($group_relationship instanceof GroupRelationshipInterface);
    assert($constraint instanceof GroupNodeRequest);

    // Apply logic only to group node request relationship.
    if ($group_relationship->getPlugin()->getBaseId() !== 'group_node_request') {
      return;
    }

    // Only run our checks if a group was referenced.
    if (!$group = $group_relationship->getGroup()) {
      return;
    }

    // Only run our checks if an entity was referenced.
    $entity = $group_relationship->getEntity();
    if (empty($entity)) {
      return;
    }

    // Already exists in the group.
    if ($group->getRelationshipsByEntity($entity, 'group_node:' . $entity->bundle())) {
      $this->context->addViolation($constraint->message, [
        '%title' => $entity->label(),
      ]);
    }

  }

}
